@@ -206,7 +206,7 @@ sub SplitterWindow {
 
    $self->{media}=$media;
 
-   $righttop->AddPage( $webpanel, "FullAuto Demonstration", 0 );
+   $righttop->AddPage( $webpanel, "FullAuto AWS Dashboard", 0 );
    $righttop->AddPage( $webpanel2, "Amazon Web Services", 0 );
    $righttop->AddPage( $webpanel3, " Amazon Web Services EC2 ", 0 );
 
@@ -331,6 +331,27 @@ sub SplitterWindow {
      $ipbox->Show(1);
      $ipbox->Enable(0) if $ip_;
      EVT_TEXT( $rightbottom, $ipbox, \&on_change );
+
+     my $chk=157;
+     my $firstpaint=0;
+     if (!exists $self->{firstpaint} && (exists $self->{ip_txt})) {
+        $chk=87;
+        $firstpaint=1;
+     }
+     $self->{firstpaint}=$firstpaint;
+     my $button4=wxPerl::Button->new(
+        $rightbottom,
+        "Cleanup",
+        id        => -1,
+        position  => [118,$chk],
+        size      => [90,-1],
+        style     => 0,
+        validator => Wx::wxDefaultValidator(),
+        name      => 'cleanup',
+     );
+     $rightbottom->{cleanup}=$button4;
+     EVT_BUTTON( $rightbottom, $button4, \&main::OnClick_button4 );
+
    }
 
    my $bmp = Wx::Bitmap->new("fakey.png",
@@ -347,21 +368,23 @@ sub SplitterWindow {
       $bb->Enable(0);
    }
 
-   my $cleanup_chkbox='';
+   #my $cleanup_chkbox='';
    my $new_server_chkbox='';
    my $export_putty_chkbox='';
    my $chk=169;
    $chk=99 if !exists $rightbottom->{firstpaint}
                           && $pem_file && $ip_txt;
-   $cleanup_chkbox=Wx::CheckBox->new($rightbottom,-1,'',
-                          [118,$chk],[-1,-1],wxTRANSPARENT_WINDOW);
-   $cleanup_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
-   $rightbottom->{cucb}=$cleanup_chkbox;
-   $self->{cucb}=$cleanup_chkbox;
-   EVT_CHECKBOX( $rightbottom, $cleanup_chkbox,
-                          \&main::OnClick_chkbox1 );
+   #$cleanup_chkbox=Wx::CheckBox->new($rightbottom,-1,'',
+   #                       [226,$chk],[-1,-1],wxTRANSPARENT_WINDOW);
+   #                       #[118,$chk],[-1,-1],wxTRANSPARENT_WINDOW);
+   #$cleanup_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
+   #$rightbottom->{cucb}=$cleanup_chkbox;
+   #$self->{cucb}=$cleanup_chkbox;
+   #EVT_CHECKBOX( $rightbottom, $cleanup_chkbox,
+   #                       \&main::OnClick_chkbox1 );
    $export_putty_chkbox=Wx::CheckBox->new($rightbottom,-1,'',
-                          [280,$chk],[-1,-1],wxTRANSPARENT_WINDOW);
+                          [118,$chk-83],[-1,-1],wxTRANSPARENT_WINDOW);
+   #                       [280,$chk],[-1,-1],wxTRANSPARENT_WINDOW);
    $export_putty_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
    $rightbottom->{epcb}=$export_putty_chkbox;
    EVT_CHECKBOX( $rightbottom, $export_putty_chkbox,
@@ -395,7 +418,7 @@ sub SplitterWindow {
          $ht=40;
       }
       my $newAni=Wx::AnimationCtrl->new(
-            $rightbottom,-1, $gif, [118,$ht], [-1,-1], 0 );
+            $rightbottom,-1, $gif, [118,$ht-9], [-1,-1], 0 );
       $newAni->Play();
    }
    $rightbottom->{ppk_file} = $ppk_file if $ppk_file;
@@ -418,7 +441,7 @@ sub SplitterWindow {
    $rightWindows->SetSashGravity(1.0);
    $splitterWindow->SplitVertically($banner,$rightWindows,142);
 
-   EVT_CLOSE( $self, \&on_close );
+   #EVT_CLOSE( $self, \&cleanup );
    EVT_MENU( $self, wxID_ABOUT, \&on_about );
    EVT_MENU( $self, wxID_EXIT, sub { $self->Close } );
    EVT_MENU( $self, wxID_COPY, \&on_copy );
@@ -445,8 +468,8 @@ sub on_paint {
     }
     $self->{firstpaint}=$firstpaint;
     $dc->DrawText('Launch New FullAuto Server',460,$chk);
-    $dc->DrawText('Cleanup on Terminate',139,$chk);
-    $dc->DrawText('Export PuTTY',301,$chk);
+    #$dc->DrawText('Preserve FullAuto Server',246,$chk);
+    $dc->DrawText('Export PuTTY',139,$chk-83);
 
 }
 
@@ -454,7 +477,9 @@ sub evt_process_exit {
 
     my ($self, $event) = @_;
     $event->Skip(1);
-    my $process = $event->GetProcess;
+    my $process=eval {
+       return $event->GetProcess;
+    };
     $process||='';
     $process->Destroy if $process;
     my $log_out='';
@@ -486,7 +511,7 @@ sub evt_process_exit {
          if ($line=~/GNU.io/ or $line=~/clipbucket[.]com/i) {
             next;
          } elsif (
-               $line=~/ACCESS (?:HADOOP|KALI|OPENLDAP|CATALYST|GNU|CLIP)/) {
+               $line=~/ACCESS (?:HADOOP|LIFERAY|KALI|OPENLDAP|CATALYST|GNU|CLIP)/) {
             last;
          } elsif ($line=~/ACCESS.*AT:\s+http:/ && $count<70) {
             $webapp_url=$line;
@@ -576,7 +601,7 @@ sub fullauto_button {
          "puttyyes \"$keybasename.ppk\" ec2-user $i",
          wxEXEC_SYNC);
       if ($rcode) {
-         my $title="FullAuto Demo Fatal Error";
+         my $title="FullAuto AWS Installer Dashboard Fatal Error";
          my $message="Fatal Error: $stderr";
          my $dialog=Wx::MessageDialog->new(
             $self,$message,$title,wxOK|wxICON_EXCLAMATION);
@@ -666,19 +691,19 @@ sub tag_for_removal {
    my $message='You have just provided an IP Address for a server '.
                'you have manually launched in the Amazon EC2 Cloud. '.
                'On this server, FullAuto will install itself, and then '.
-               'proceed with the Demonstration where FullAuto will stand '.
+               'proceed with processing where FullAuto will stand '.
                'up other servers, and exhibit the completely automated '.
                'installation and startup of complex software/application '.
                'architecture spanning multiple hosts. If you click the '.
                'button \'Tag for Removal\', FullAuto will terminate this '.
-               'server along with all servers launched for the Demonstation '.
+               'server along with all servers launched for the session '.
                'when you click the checkbox \'Cleanup on Terminate\' at the '.
-               "bottom of the FullAuto Demonstration interface.\n\nWould you ".
+               "bottom of the FullAuto AWS Dashboard interface.\n\nWould you ".
                "like to tag this server for later termination?\n\n(If you ".
-               'are new to the Cloud, and only wish to view the FullAuto '.
-               'Demonstration, it is recommended you choose \'Tag for '.
+               'are new to the Cloud, and only wish to test drive FullAuto, '.
+               'it is recommended you choose \'Tag for '.
                'Removal\', and later check the box \'Cleanup on Terminate\' '.
-               'when you are done with the Demonstration, so that you don\'t '.
+               'when you are done with the session, so that you don\'t '.
                'incur any unnecessary Amazon fees.)';
    my $dialog=Wx::MessageDialog->new(
       $self,$message,$title,wxOK|wxCANCEL|wxICON_EXCLAMATION);
@@ -698,18 +723,19 @@ sub OnClick_chkbox1 {
    my ($self, $event) =@_;
    my $title='Cleanup on Terminate?';
    my $message='When this box is checked, upon termination of the '.
-               'FullAuto Automates EVERYTHING Demonstration window, '.
+               'FullAuto AWS Installer Dashboard window, '.
                'a cleanup process is launched which will destroy all the '.
-               'servers this Demo creates on Amazon EC2, as well as all files '.
+               'servers this session creates on Amazon EC2, as well as all files '.
                'cached locally. NOTHING will be saved except for this '.
-               'FullAuto_DEMO_MSWin.exe file itself, which you '.
+               'FullAuto-AWS-Installer-Dashboard-MSWin.exe file itself, which you '.
                'may manually delete. You will have to launch a '.
                'new FullAuto server from Amazon and download a new '.
-               'key file and credentials file to run the Demo again, '.
-               'if you terminate this instance of the Demo with this '.
+               'key file and credentials file to run a session again, '.
+               'if you terminate this instance of the Dashboard with this '.
                'box checked. So it is recommended that you DO NOT have '.
                'this box checked until you are pretty certain you have no '.
-               'more need to run the FullAuto Demo, for yourself or others.';
+               'more need to run the FullAuto AWS Installer Dashboard, '.
+               'for yourself or others.';
    my $dialog=Wx::MessageDialog->new(
       $self,$message,$title,wxOK|wxCANCEL|wxICON_EXCLAMATION);
    $dialog->SetOKCancelLabels('OK','CANCEL Cleanup');
@@ -762,7 +788,7 @@ sub OnClick_chkbox3 {
                'API. Then you will have to wait at least 20 minutes for '.
                'a new FullAuto setup to be downloaded and installed on the '.
                'new FullAuto server before you can obtain the same setup, '.
-               'access, and ability to run and view the Demo that you have '.
+               'access, and ability to run and view the session that you have '.
                "now.\n\nYOU CANNOT REVERSE THIS DECISION!\n\nOnce you proceed ".
                'with the choise to Launch a new FullAuto Server, the '.
                'currently active credentials will be permanently discarded '.
@@ -782,17 +808,17 @@ sub OnClick_chkbox3 {
                'pre-existing if you have one that is still active. You will '.
                'again have to wait at least 20 minutes for a new FullAuto '.
                'install to take place before you can obtain the same setup '.
-               'access, and ability to run and view the Demp that have now. '.
+               'access, and ability to run and view the session that have now. '.
                "\n\nYOU CANNOT REVERSE THIS DECISION!\n\nOnce you proceed ".
                'with the choice to Launch a new FullAuto Server, the current '.
                'settings will be permanently discarded and unrecoverable '.
                "(except by manual re-entry.)\n\nDo you still wish to proceed?";
    } else {
       $self->{nscb}->SetValue(1);
-      $message='There are no saved settings, and a Demo is not currently '.
-               'running. To run the FullAuto Demo, a fully functioning '.
+      $message='There are no saved settings, and a session is not currently '.
+               'running. To run any FullAuto Instruction Set, a fully functioning '.
                'FullAuto Server is necessary, which it is the job of this '.
-               'FullAuto_DEMO_MSWin.exe application/utility to assist you '.
+               'FullAuto-AWS-Installer-Dashboard-MSWin.exe application/utility to assist you '.
                'with. Therefore, this box will remain checked until such '.
                'time as the first FullAuto Server install has been launched';
       my $dialog=Wx::MessageDialog->new(
@@ -848,6 +874,13 @@ sub OnClick_button3 {
 
 }
 
+sub OnClick_button4 {
+
+   my ($self, $event) =@_;
+   &cleanup($self,$event);
+
+}
+
 sub on_drop {
 
     my( $self, $wxDropFilesEvent ) = @_;
@@ -1010,159 +1043,185 @@ sub search {
    return;
 }
 
-sub on_close {
+sub cleanup {
 
    my( $self, $event ) = @_;
-   chdir $self->{begin_cwd};
-   $event->Skip;
+   $event->Skip if $event;
+   chdir "../../..";
    my $cwd=cwd();
-   if ($self->{cucb}->IsChecked()) {
-      if (exists $ENV{PAR_TEMP}) {
-         chdir "$ENV{PAR_TEMP}\\inc";
-         copy "cmds_cleanup.template", "cmds.txt";
-         my $ppk_file='';my $saved_txt;my $full_pem='';
-         my $cre_file='';my $tagged='';
-         opendir(PH,'.');
-         while (my $f=readdir(PH)) {
-            next if $f eq '.';
-            next if $f eq '..';
-            if ($f=~/\.ppk$/) {
-               $ppk_file=$f;
-            } elsif ($f=~/^saved.txt$/) {
-               open(FH,"<saved.txt") || warn $!;
-               my @lines=<FH>;
-               close FH;
-               foreach my $line (@lines) {
-                  chomp $line;
-                  $saved_txt=$line if
-                     $line=~s/^\s*.*?(\d+[.]\d+[.]\d+[.]\d+).*$/$1/s;
-                  $ppk_file=$line if $line=~/ppk$/;
-                  $full_pem=$line if $line=~/pem$/;
-                  $cre_file=$line if $line=~/csv$/;
-                  $tagged=$line if $line=~/TagFA/;
-               }
-               $tagged=~s/TagFA=// if $tagged;
+   my $title='Continue with Cleanup of FullAuto?';
+   my $message="You have pushed the Cleanup button. If you choose to continue, a process will\n".
+               "launch that will remove all FullAuto files cached locally when you first ran\n".
+               "the FullAuto AWS Installer Dashboard. NOTHING will be saved except for the\n".
+               "FullAuto-AWS-Installer-Dashboard-MSWin.exe file, which you may manually\n".
+               "delete. If you later wish to use the Dashboard again, you will have to again\n".
+               "populate the key file, credentials file and IP Address boxes. If you think you\n".
+               "want to run additional FullAuto Instruction Sets in the near future, FullAuto\n".
+               "saves these entries for re-use by default. However, these settings are\n".
+               "permanently lost if you continue Cleanup.\n\n".
+               "By default, Cleanup will connect to Amazon AWS EC2 and terminate the FullAuto\n".
+               "server indicated in the IP Address box. If you don't anticipate needing the\n".
+               "FullAuto server further, terminating it will save you Amazon AWS EC2 charges.\n".
+               "You can always build a new one from scratch in just a few minutes. If you want\n".
+               "to cleanup the local files, but keep the FullAuto server in Amazon, check the\n".
+               "checkbox below.\n\n".
+               "NOTE: Cleanup will not touch anything built with FullAuto Instruction Sets.\n".
+               "      To clean up those servers, use the AWS Console ->\n".
+               "      https://console.aws.amazon.com";
+   my @choices = ("DO NOT terminate FullAuto Server");
+   my $multiChoiceDialog = Wx::MultiChoiceDialog->new($self, $message, $title, \@choices);
+   my $terminate_fullauto_server=0;
+   if ($multiChoiceDialog->ShowModal() == wxID_OK) {
+      my @selections = $multiChoiceDialog->GetSelections();
+      $terminate_fullauto_server = $#selections +1;
+   } else {
+      return
+   }
+   if (exists $ENV{PAR_TEMP}) {
+      chdir "$ENV{PAR_TEMP}\\inc";
+      copy "cmds_cleanup.template", "cmds.txt";
+      my $ppk_file='';my $saved_txt;my $full_pem='';
+      my $cre_file='';my $tagged='';
+      opendir(PH,'.');
+      while (my $f=readdir(PH)) {
+         next if $f eq '.';
+         next if $f eq '..';
+         if ($f=~/\.ppk$/) {
+            $ppk_file=$f;
+         } elsif ($f=~/^saved.txt$/) {
+            open(FH,"<saved.txt") || warn $!;
+            my @lines=<FH>;
+            close FH;
+            foreach my $line (@lines) {
+               chomp $line;
+               $saved_txt=$line if
+                  $line=~s/^\s*.*?(\d+[.]\d+[.]\d+[.]\d+).*$/$1/s;
+               $ppk_file=$line if $line=~/ppk$/;
+               $full_pem=$line if $line=~/pem$/;
+               $cre_file=$line if $line=~/csv$/;
+               $tagged=$line if $line=~/TagFA/;
             }
+            $tagged=~s/TagFA=// if $tagged;
          }
-         my $i=$self->{ipbox}->GetLineText(0);
-         my $pem=$full_pem;
-         $pem=~s/^.*\\(.*)/$1/;
-         if (-e "cmds.txt") {
-            open(FH,"+<cmds.txt") || warn $!;
-            my $out='';
-            while(my $line=<FH>) {
-               $line=~s/_p_/$pem/eg;
-               $line=~s/_c_/$tagged/eg;
-               $out.=$line;
-            }
-            seek(FH,0,0);
-            print FH $out;
-            truncate(FH,tell(FH));
-            close(FH);
-            my $ping=Wx::ExecuteStdout("tcping $i 22",wxEXEC_SYNC);
-            $ping=join '',@{$ping};
-            if ((-1<index $ping,'Port is open') && $ppk_file) {
-               my $cmd="runcleanup \"$ppk_file\" $i";
-               Wx::ExecuteCommand($cmd,wxEXEC_SYNC)
-            }
+      }
+      my $i=$self->{ipbox}->GetLineText(0);
+      my $pem=$full_pem;
+      $pem=~s/^.*\\(.*)/$1/;
+      if (-e "cmds.txt" && $terminate_fullauto_server) {
+         open(FH,"+<cmds.txt") || warn $!;
+         my $out='';
+         while(my $line=<FH>) {
+            $line=~s/_p_/$pem/eg;
+            $line=~s/_c_/$tagged/eg;
+            $out.=$line;
          }
-         my $pardir=$ENV{PAR_TEMP}||'';
-         $pardir=~s/^(.*)\\.*$/$1/;
-         copy "saved.txt", "saved.txt.bak";
-         unlink "saved.txt";
-         copy "putty.log", "putty.log.bak";
-         chdir $cwd;
-         open(FH,">clean_fullauto_demo.bat");
-         print FH "ping 127.0.0.1 -n 1 -w 2000 > nul\n";
-         print FH "del /S /Q $pardir\\inc\\putty.log\n";
-         print FH "rmdir /S /Q $pardir\n";
-         print FH "ping 127.0.0.1 -n 1 -w 2000 > nul\n";
-         print FH "del /S /Q $pardir\\inc\\putty.log\n";
-         print FH "rmdir /S /Q $pardir\n";
-         print FH 'start /b "" cmd /c del "%~f0"&exit /b';
-         close FH;
-         my $sessions=
-               'HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\Sessions';
-         my $sshhkeys=
-               'HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\SshHostKeys';
-         my $jumplist=
-               'HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\Jumplist';
-         my @sessions=();my $ses='';
-         open(FH,"reg query $sessions|");
+         seek(FH,0,0);
+         print FH $out;
+         truncate(FH,tell(FH));
+         close(FH);
+         my $ping=Wx::ExecuteStdout("tcping $i 22",wxEXEC_SYNC);
+         $ping=join '',@{$ping};
+         if ((-1<index $ping,'Port is open') && $ppk_file) {
+            my $cmd="runcleanup \"$ppk_file\" $i";
+            Wx::ExecuteCommand($cmd,wxEXEC_SYNC)
+         }
+      }
+      my $pardir=$ENV{PAR_TEMP}||'';
+      $pardir=~s/^(.*)\\.*$/$1/;
+      copy "saved.txt", "saved.txt.bak";
+      unlink "saved.txt";
+      copy "putty.log", "putty.log.bak";
+      chdir $cwd;
+      open(FH,">clean_fullauto.bat");
+      print FH "ping 127.0.0.1 -n 1 -w 6000 > nul\n";
+      print FH "del /S /Q $pardir\\inc\\putty.log\n";
+      print FH "rmdir /S /Q $pardir\n";
+      print FH "ping 127.0.0.1 -n 1 -w 6000 > nul\n";
+      print FH "del /S /Q $pardir\\inc\\putty.log\n";
+      print FH "rmdir /S /Q $pardir\n";
+      print FH 'start /b "" cmd /c del "%~f0"&exit /b';
+      close FH;
+      my $sessions=
+            'HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\Sessions';
+      my $sshhkeys=
+            'HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\SshHostKeys';
+      my $jumplist=
+            'HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\Jumplist';
+      my @sessions=();my $ses='';
+      open(FH,"reg query $sessions|");
+      while (my $line=<FH>) {
+         next if $line=~/^\s*$/;
+         if (-1<index $line, 'FullAuto') {
+            chomp($line);
+            my $key=$line;
+            $key=~s/^.*\\(.*)\s*$/$1/s;
+            push @sessions, $key;
+            open (DH,"reg delete $line /f 2>&1|");
+            while (my $line=<DH>) {
+               print $line;
+            }
+            close DH;
+         }
+      }
+      close FH;
+      foreach my $session (@sessions) {
+         my $ip=$session;
+         $ip=~s/^.*_(.*)$/$1/;
+         chomp($ip);
+         open(FH,"reg query $sshhkeys|");
          while (my $line=<FH>) {
             next if $line=~/^\s*$/;
-            if (-1<index $line, 'FullAuto') {
-               chomp($line);
+            if (-1<index $line, $ip) {
                my $key=$line;
-               $key=~s/^.*\\(.*)\s*$/$1/s;
-               push @sessions, $key;
-               open (DH,"reg delete $line /f 2>&1|");
+               $line=~s/^\s+(.*?)\s+.*$/$1/;
+               open (DH,"reg delete $sshhkeys /f /v \"$line\" 2>&1|");
                while (my $line=<DH>) {
                   print $line;
                }
                close DH;
+               last;
             }
          }
-         close FH;
-         foreach my $session (@sessions) {
-            my $ip=$session;
-            $ip=~s/^.*_(.*)$/$1/;
-            chomp($ip);
-            open(FH,"reg query $sshhkeys|");
-            while (my $line=<FH>) {
-               next if $line=~/^\s*$/;
-               if (-1<index $line, $ip) {
-                  my $key=$line;
-                  $line=~s/^\s+(.*?)\s+.*$/$1/;
-                  open (DH,"reg delete $sshhkeys /f /v \"$line\" 2>&1|");
+         open(FH,"reg query $jumplist|");
+         while (my $line=<FH>) {
+            next if $line=~/^\s*$/;
+            if ($line=~/FullAuto/) {
+               my @rsess=split " |.0", $line;
+               foreach my $rs (@rsess) {
+                  next if $rs=~/^\s*$/;
+                  next if -1<index $rs,'Recent';
+                  next if -1<index $rs,'sessions';
+                  next if -1<index $rs,'REG_MULTI_SZ';
+                  next if -1<index $rs,'FullAuto';
+                  $ses.="$rs ";
+               }
+               $ses=~s/\s*$//;
+               open (DH,
+                  "reg delete $jumplist /f /v \"Recent sessions\" 2>&1|");
+               while (my $line=<DH>) {
+                  print $line;
+               }
+               close DH;
+               if ($ses) {
+                  my $c="reg add $jumplist /f /v \"Recent sessions\" /t ".
+                        "REG_MULTI_SZ /d \"$ses\"";
+                  open (DH,"$c 2>&1|");
                   while (my $line=<DH>) {
                      print $line;
                   }
                   close DH;
-                  last;
-               }
-            }
-            open(FH,"reg query $jumplist|");
-            while (my $line=<FH>) {
-               next if $line=~/^\s*$/;
-               if ($line=~/FullAuto/) {
-                  my @rsess=split " |.0", $line;
-                  foreach my $rs (@rsess) {
-                     next if $rs=~/^\s*$/;
-                     next if -1<index $rs,'Recent';
-                     next if -1<index $rs,'sessions';
-                     next if -1<index $rs,'REG_MULTI_SZ';
-                     next if -1<index $rs,'FullAuto';
-                     $ses.="$rs ";
-                  }
-                  $ses=~s/\s*$//;
-                  open (DH,
-                     "reg delete $jumplist /f /v \"Recent sessions\" 2>&1|");
-                  while (my $line=<DH>) {
-                     print $line;
-                  }
-                  close DH;
-                  if ($ses) {
-                     my $c="reg add $jumplist /f /v \"Recent sessions\" /t ".
-                           "REG_MULTI_SZ /d \"$ses\"";
-                     open (DH,"$c 2>&1|");
-                     while (my $line=<DH>) {
-                        print $line;
-                     }
-                     close DH;
-                  }
-                  last;
                }
+               last;
             }
          }
-         my @arg=("clean_fullauto_demo.bat");
-         exec @arg;
       }
-      copy "saved.txt", "saved.txt.bak";
-      unlink "saved.txt";
-      copy "putty.log", "putty.log.bak";
-      unlink "putty.log";
+      my @arg=("clean_fullauto.bat");
+      exec @arg;
    }
+   copy "saved.txt", "saved.txt.bak";
+   unlink "saved.txt";
+   copy "putty.log", "putty.log.bak";
+   unlink "putty.log";
 
 }
 
@@ -1173,9 +1232,9 @@ sub on_about {
 
    my $info = Wx::AboutDialogInfo->new;
 
-   $info->SetName( "FullAuto Demonstration" );
+   $info->SetName( "FullAuto AWS Installer Dashboard" );
    $info->SetVersion( '0.01' );
-   $info->SetDescription( 'FullAuto Automates EVERYTHING Demonstration' );
+   $info->SetDescription( 'FullAuto Automates EVERYTHING AWS Installer Dashboard' );
    $info->SetCopyright(
       "(c) 2000-2016 Brian Kelly <Brian.Kelly\@FullAutoSoftware.net>" );
    $info->SetWebSite(
